@@ -1,6 +1,6 @@
-#' Compare two NP classification methods at different thresholds.
+#' Compare two NP classification methods at different type I error upper bounds.
 #'
-#' \code{compare} compares NP classification methods and provide the regions where one method is better than the other. The two NP-ROC curves are both required to have band = TRUE.
+#' \code{compare} compares NP classification methods and provides the regions where one method is better than the other.
 #' @export
 #' @param roc1 the first nproc object.
 #' @param roc2 the second nproc object.
@@ -11,7 +11,6 @@
 #' \item{alpha1}{the alpha values where roc1 is significantly better than roc2. }
 #' \item{alpha2}{the alpha values where roc2 is significantly better than roc1. }
 #' \item{alpha3}{the alpha values where roc1 and roc2 are not significantly different.}
-#' \item{confidence}{represents the confidence level.}
 #' @seealso \code{\link{npc}}, \code{\link{nproc}}, \code{\link{predict.npc}} and \code{\link{plot.nproc}}
 #' @references
 #' Xin Tong, Yang Feng, and Jingyi Jessica Li (2016), Neyman-Pearson (NP) classification algorithms and NP receiver operating characteristic (NP-ROC) curves, manuscript, http://arxiv.org/abs/1608.03109.
@@ -21,24 +20,22 @@
 #' x1 = c(rnorm(n), rnorm(n) + 1)
 #' x2 = c(rnorm(n), rnorm(n)*sqrt(6) + 1)
 #' y = c(rep(0,n), rep(1,n))
-#' fit1 = nproc(x1, y, band = TRUE, method = 'lda')
-#' fit2 = nproc(x2, y, band = TRUE, method = 'lda')
+#' fit1 = nproc(x1, y, method = 'lda')
+#' fit2 = nproc(x2, y, method = 'lda')
 #' v = compare(fit1, fit2)
 #' legend('topleft',legend=c('x1','x2'),col=1:2,lty=c(1,1))
 #'
 compare <- function(roc1, roc2, plot = TRUE, col1 = "black", col2 = "red") {
 
-    if (is.null(roc1$band) | is.null(roc2$band)) {
-        stop("the two nproc objects need to have band = TRUE.")
-    }
     alphalist = roc1$typeI.u
     loc1 = roc1$typeII.u < roc2$typeII.l
     loc2 = roc1$typeII.l > roc2$typeII.u
     alpha1 = alphalist[loc1]
     alpha2 = alphalist[loc2]
     alpha3 = setdiff(alphalist, c(alpha1, alpha2))
-    delta = roc1$delta/2 + roc2$delta/2
-
+    if(roc1$delta != roc2$delta){
+      stop("The two nproc objects need to have the same delta.")
+    }
     if (plot == TRUE) {
         plot(roc1, col = col1)
         lines(roc2, col = col2)
@@ -59,6 +56,6 @@ compare <- function(roc1, roc2, plot = TRUE, col1 = "black", col2 = "red") {
     }
 
 
-    return(list(alpha1 = alpha1, alpha2 = alpha2, alpha3 = alpha3, confidence = 1 - delta))
+    return(list(alpha1 = alpha1, alpha2 = alpha2, alpha3 = alpha3))
 }
 
